@@ -2,7 +2,7 @@
 class RPC extends Handler_Protected {
 
 	function csrf_ignore($method) {
-		$csrf_ignored = array("sanitycheck", "buttonplugin", "exportget", "sharepopup");
+		$csrf_ignored = array("sanitycheck", "buttonplugin", "exportget", "completelabels");
 
 		return array_search($method, $csrf_ignored) !== false;
 	}
@@ -426,6 +426,23 @@ class RPC extends Handler_Protected {
 		print json_encode(array("link" => $new_link));
 	}
 
+	function completeLabels() {
+		$search = db_escape_string($_REQUEST["search"]);
+
+		$result = db_query($this->link, "SELECT DISTINCT caption FROM
+				ttrss_labels2
+				WHERE owner_uid = '".$_SESSION["uid"]."' AND
+				LOWER(caption) LIKE LOWER('$search%') ORDER BY caption
+				LIMIT 5");
+
+		print "<ul>";
+		while ($line = db_fetch_assoc($result)) {
+			print "<li>" . $line["caption"] . "</li>";
+		}
+		print "</ul>";
+	}
+
+
 	function completeTags() {
 		$search = db_escape_string($_REQUEST["search"]);
 
@@ -681,7 +698,6 @@ class RPC extends Handler_Protected {
 		return;
 	}
 
-
 	function verifyRegexp() {
 		$reg_exp = $_REQUEST["reg_exp"];
 
@@ -690,75 +706,6 @@ class RPC extends Handler_Protected {
 		print json_encode(array("status" => $status));
 	}
 
-	// TODO: unify with digest-get-contents?
-	function cdmGetArticle() {
-		$ids = array(db_escape_string($_REQUEST["id"]));
-		$cids = explode(",", $_REQUEST["cids"]);
-
-		$ids = array_merge($ids, $cids);
-
-		$rv = array();
-
-		foreach ($ids as $id) {
-			$id = (int)$id;
-
-			$result = db_query($this->link, "SELECT content,
-					ttrss_feeds.site_url AS site_url FROM ttrss_user_entries, ttrss_feeds,
-					ttrss_entries
-					WHERE feed_id = ttrss_feeds.id AND ref_id = '$id' AND
-					ttrss_entries.id = ref_id AND
-					ttrss_user_entries.owner_uid = ".$_SESSION["uid"]);
-
-			if (db_num_rows($result) != 0) {
-				$line = db_fetch_assoc($result);
-
-				$article_content = sanitize($this->link, $line["content"],
-					false, false, $line['site_url']);
-
-				array_push($rv,
-					array("id" => $id, "content" => $article_content));
-			}
-		}
-
-		print json_encode($rv);
-	}
-
-	function scheduleFeedUpdate() {
-		$feed_id = db_escape_string($_REQUEST["id"]);
-		$is_cat =  db_escape_string($_REQUEST['is_cat']) == 'true';
-
-		$message = __("Your request could not be completed.");
-
-		if ($feed_id >= 0) {
-			if (!$is_cat) {
-				$message = __("Feed update has been scheduled.");
-
-				db_query($this->link, "UPDATE ttrss_feeds SET
-					last_update_started = '1970-01-01',
-					last_updated = '1970-01-01' WHERE id = '$feed_id' AND
-					owner_uid = ".$_SESSION["uid"]);
-
-			} else {
-				$message = __("Category update has been scheduled.");
-
-				if ($feed_id)
-				$cat_query = "cat_id = '$feed_id'";
-				else
-				$cat_query = "cat_id IS NULL";
-
-				db_query($this->link, "UPDATE ttrss_feeds SET
-						last_update_started = '1970-01-01',
-						last_updated = '1970-01-01' WHERE $cat_query AND
-						owner_uid = ".$_SESSION["uid"]);
-			}
-		} else {
-			$message = __("Can't update this kind of feed.");
-		}
-
-		print json_encode(array("message" => $message));
-		return;
-	}
-
 	function buttonPlugin() {
 		$pclass = "button_" . basename($_REQUEST['plugin']);
 		$method = $_REQUEST['plugin_method'];
@@ -816,5 +763,16 @@ class RPC extends Handler_Protected {
 		}
 	}
 
+	function setScore() {
+		$ids = db_escape_string($_REQUEST['id']);
+		$score = (int)db_escape_string($_REQUEST['score']);
+
+		db_query($this->link, "UPDATE ttrss_user_entries SET
+			score = '$score' WHERE ref_id IN ($ids) AND owner_uid = " . $_SESSION["uid"]);
+
+		print json_encode(array("id" => $id,
+			"score_pic" => theme_image($link, get_score_pic($score))));
+	}
+
 }
 ?>
