@@ -838,8 +838,9 @@ function quickAddFeed() {
 	try {
 		var query = "backend.php?op=dlg&method=quickAddFeed";
 
-		if (dijit.byId("feedAddDlg"))
-			dijit.byId("feedAddDlg").destroyRecursive();
+		// overlapping widgets
+		if (dijit.byId("batchSubDlg")) dijit.byId("batchSubDlg").destroyRecursive();
+		if (dijit.byId("feedAddDlg"))	dijit.byId("feedAddDlg").destroyRecursive();
 
 		var dialog = new dijit.Dialog({
 			id: "feedAddDlg",
