@@ -13,6 +13,7 @@ var feed_precache_timeout_id = false;
 var precache_idle_timeout_id = false;
 
 var cids_requested = [];
+var loaded_article_ids = [];
 
 var has_storage = 'sessionStorage' in window && window['sessionStorage'] !== null;
 
@@ -53,6 +54,10 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 
 			setActiveFeedId(feed_id, is_cat);
 
+			dijit.getEnclosingWidget(
+				document.forms["main_toolbar_form"].update).attr('disabled',
+					is_cat || feed_id <= 0);
+
 			try {
 				if (offset == 0 && infscroll_req == false) {
 					$("headlines-frame").scrollTop = 0;
@@ -74,6 +79,8 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 			//var runtime_info = reply['runtime-info'];
 
 			if (offset == 0 && infscroll_req == false) {
+				loaded_article_ids = [];
+
 				dijit.byId("headlines-frame").attr('content',
 					reply['headlines']['content']);
 
@@ -81,8 +88,10 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 					reply['headlines']['toolbar']);
 
 				$$("#headlines-frame > div[id*=RROW]").each(function(row) {
-					if ($$("#headlines-frame DIV[id="+row.id+"]").length > 1) {
+					if (loaded_article_ids.indexOf(row.id) != -1) {
 						row.parentNode.removeChild(row);
+					} else {
+						loaded_article_ids.push(row.id);
 					}
 				});
 
@@ -94,6 +103,12 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 
 				initHeadlinesMenu();
 
+				if (_search_query) {
+					$("feed_title").innerHTML += "<span id='cancel_search'>" +
+						" (<a href='#' onclick='cancelSearch()'>" + __("Cancel search") + "</a>)" +
+						"</span>";
+				}
+
 			} else {
 
 				if (headlines_count > 0 && feed_id == getActiveFeedId() && is_cat == activeFeedIsCat()) {
@@ -101,7 +116,7 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 
 					var c = dijit.byId("headlines-frame");
 					var ids = getSelectedArticleIds2();
-					var num_added = 0;
+					var new_elems = [];
 
 					$("headlines-tmp").innerHTML = reply['headlines']['content'];
 
@@ -111,10 +126,15 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 						c.domNode.removeChild(hsp);
 
 					$$("#headlines-tmp > div").each(function(row) {
-						if ($$("#headlines-frame DIV[id="+row.id+"]").length == 0) {
+						if (row.className == 'cdmFeedTitle') {
 							row.style.display = 'none';
 							c.domNode.appendChild(row);
-							++num_added;
+							new_elems.push(row);
+						} else if (loaded_article_ids.indexOf(row.id) == -1) {
+							row.style.display = 'none';
+							c.domNode.appendChild(row);
+							new_elems.push(row);
+							loaded_article_ids.push(row.id);
 						} else {
 							row.parentNode.removeChild(row);
 						}
@@ -128,9 +148,9 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 						c.domNode.appendChild(hsp);
 					}
 
-					console.log("added " + num_added + " headlines");
+					console.log("added " + new_elems.size() + " headlines");
 
-					if (num_added == 0)
+					if (new_elems.size() == 0)
 						_infscroll_disable = true;
 
 					console.log("restore selected ids: " + ids);
@@ -141,8 +161,7 @@ function headlines_callback2(transport, offset, background, infscroll_req) {
 
 					initHeadlinesMenu();
 
-					$$("#headlines-frame > div[id*=RROW]").each(
-					function(child) {
+					new_elems.each(function(child) {
 						if (!Element.visible(child))
 							new Effect.Appear(child, { duration : 0.5 });
 					});
@@ -1322,52 +1341,6 @@ function cdmExpandArticle(id) {
 		if (!Element.visible(elem)) {
 			Element.show(elem);
 			Element.hide("CEXC-" + id);
-
-			if ($("CWRAP-" + id).innerHTML == "") {
-
-				$("FUPDPIC-" + id).src = "images/indicator_tiny.gif";
-
-				$("CWRAP-" + id).innerHTML = "<div class=\"insensitive\">" +
-					__("Loading, please wait...") + "</div>";
-
-				var query = "?op=rpc&method=cdmGetArticle&id=" + param_escape(id);
-
-				var neighbor_ids = getRelativePostIds(id);
-
-				/* only request uncached articles */
-				var cids_to_request = [];
-
-				for (var i = 0; i < neighbor_ids.length; i++) {
-					if (cids_requested.indexOf(neighbor_ids[i]) == -1)
-						if ($("CWRAP-" + neighbor_ids[i]).innerHTML == "") {
-							cids_to_request.push(neighbor_ids[i]);
-							cids_requested.push(neighbor_ids[i]);
-						}
-				}
-
-				console.log("additional ids: " + cids_to_request.toString());
-
-				query = query + "&cids=" + cids_to_request.toString();
-
-				console.log(query);
-
-				new Ajax.Request("backend.php", {
-					parameters: query,
-					onComplete: function(transport) {
-
-						$("FUPDPIC-" + id).src = 'images/blank_icon.gif';
-
-						handle_rpc_json(transport);
-
-						var reply = JSON.parse(transport.responseText);
-
-						reply.each(function(article) {
-							$("CWRAP-" + article['id']).innerHTML = article['content'];
-							cids_requested.remove(article['id']);
-						});
-				}});
-
-			}
 		}
 
 		var new_offset = $("RROW-" + id).offsetTop;
@@ -2096,6 +2069,10 @@ function render_local_headlines(feed, is_cat, obj) {
 		setActiveFeedId(feed, is_cat);
 		initHeadlinesMenu();
 
+		dijit.getEnclosingWidget(
+			document.forms["main_toolbar_form"].update).attr('disabled',
+				is_cat || feed <= 0);
+
 		precache_headlines();
 
 	} catch (e) {
@@ -2154,4 +2131,83 @@ function precache_headlines() {
 	}
 }
 
+function cancelSearch() {
+	try {
+		_search_query = "";
+		viewCurrentFeed();
+	} catch (e) {
+		exception_error("cancelSearch", e);
+	}
+}
 
+function setSelectionScore() {
+	try {
+		var ids = getSelectedArticleIds2();
+
+		if (ids.length > 0) {
+			console.log(ids);
+
+			var score = prompt(__("Please enter new score for selected articles:"), score);
+
+			if (score != undefined) {
+				var query = "op=rpc&method=setScore&id=" + param_escape(ids.toString()) +
+					"&score=" + param_escape(score);
+
+				new Ajax.Request("backend.php", {
+					parameters: query,
+					onComplete: function(transport) {
+						var reply = JSON.parse(transport.responseText);
+						if (reply) {
+							console.log(ids);
+
+							ids.each(function(id) {
+								var row = $("RROW-" + id);
+
+								if (row) {
+									var pic = row.getElementsByClassName("hlScorePic")[0];
+
+									if (pic) {
+										pic.src = pic.src.replace(/score_.*?\.png/,
+											reply["score_pic"]);
+										pic.setAttribute("score", score);
+									}
+								}
+							});
+						}
+					} });
+			}
+
+		} else {
+			alert(__("No articles are selected."));
+		}
+	} catch (e) {
+		exception_error("setSelectionScore", e);
+	}
+}
+
+function changeScore(id, pic) {
+	try {
+		var score = pic.getAttribute("score");
+
+		var new_score = prompt(__("Please enter new score for this article:"), score);
+
+		if (new_score != undefined) {
+
+			var query = "op=rpc&method=setScore&id=" + param_escape(id) +
+				"&score=" + param_escape(new_score);
+
+			new Ajax.Request("backend.php", {
+				parameters: query,
+				onComplete: function(transport) {
+					var reply = JSON.parse(transport.responseText);
+
+					if (reply) {
+						pic.src = pic.src.replace(/score_.*?\.png/, reply["score_pic"]);
+						pic.setAttribute("score", new_score);
+					}
+				} });
+		}
+	} catch (e) {
+		exception_error("changeScore", e);
+	}
+}
