@@ -28,15 +28,17 @@ function do_login() {
         <a class="button blueButton" onclick='do_login()'><?php echo __('Log in') ?></a>
     </div>
 
-	<form target="_self" title="Login" action="index.php" id="login" class="panel" method="post" name="login" selected="true">
+	<form target="_self" title="Login" id="login" class="panel" name="login" selected="true"
+		action="../public.php?return=<?php echo htmlspecialchars($_SERVER["REQUEST_URI"]) ?>"
+		method="post">
+
+	<input type="hidden" name="op" value="login">
 
 	<fieldset>
 
-		<input type="hidden" name="login_action" value="do_login">
-
 		<div class="row">
 			<label><?php echo __("Login:") ?></label>
-			<input type="text" name="login">
+			<input type="text" autocapitalize="off" name="login">
 		</div>
 
 		<div class="row">
@@ -45,7 +47,10 @@ function do_login() {
 		</div>
 
 		</fieldset>
-	
+
+		<div align='center'><a target='_self' href='<?php echo get_self_url_prefix() ?>/index.php?mobile=false'>
+			<?php echo __("Open regular version") ?></a>
+
 	</form>
 
 </body>
